@@ -1,7 +1,7 @@
 project = "pgqueuer"
 copyright = "2024, JeeyBee"
 author = "JeeyBee"
-extensions = ["myst_parser"]
+extensions = ["myst_parser", "sphinxcontrib.mermaid"]
 templates_path = ["_templates"]
 exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 html_static_path = ["_static"]
