@@ -1,10 +1,12 @@
 from __future__ import annotations
 
 import sys
+from functools import partial
 from http import HTTPStatus
 from pathlib import Path
 from typing import Generator
 
+import asyncpg
 import pytest
 from fastapi.testclient import TestClient
 
@@ -14,6 +16,15 @@ sys.path.insert(0, str(Path(__file__).resolve().parents[2]))
 from examples.fastapi_usage import create_app
 
 
+@pytest.fixture(autouse=True)
+def patch_asyncpg(dsn: str, monkeypatch: pytest.MonkeyPatch) -> None:
+    monkeypatch.setattr(
+        asyncpg,
+        "create_pool",
+        partial(asyncpg.create_pool, dsn=dsn),
+    )
+
+
 @pytest.fixture
 def client() -> Generator[TestClient, None, None]:
     with TestClient(create_app()) as client:
