@@ -19,11 +19,12 @@ async def test_cancellation_async(
     event = asyncio.Event()
     cancel_called_not_cancel_called = list[bool]()
     q = Queries(apgdriver)
-    qm = QueueManager(apgdriver)
+    qm = QueueManager(apgdriver, resources={"test_key": "async"})
 
     @qm.entrypoint("to_be_canceled")
     async def to_be_canceled(job: Job) -> None:
         scope = qm.get_context(job.id).cancellation
+        assert qm.get_context(job.id).resources["test_key"] == "async"
         await event.wait()
         cancel_called_not_cancel_called.append(scope.cancel_called)
 
@@ -62,12 +63,13 @@ async def test_cancellation_sync(
     event = threading.Event()
     cancel_called_not_cancel_called = list[bool]()
     q = Queries(apgdriver)
-    qm = QueueManager(apgdriver)
+    qm = QueueManager(apgdriver, resources={"test_key": "sync"})
 
     @qm.entrypoint("to_be_canceled")
     def to_be_canceled(job: Job) -> None:
         nonlocal event
         scope = qm.get_context(job.id).cancellation
+        assert qm.get_context(job.id).resources["test_key"] == "sync"
         event.wait()
         cancel_called_not_cancel_called.append(scope.cancel_called)
 
@@ -105,11 +107,12 @@ async def test_cancellation_async_context_manager(
     event = asyncio.Event()
     cancel_called_not_cancel_called = list[bool]()
     q = Queries(apgdriver)
-    qm = QueueManager(apgdriver)
+    qm = QueueManager(apgdriver, resources={"test_key": "async_cm"})
 
     @qm.entrypoint("to_be_canceled")
     async def to_be_canceled(job: Job) -> None:
         with qm.get_context(job.id).cancellation as scope:
+            assert qm.get_context(job.id).resources["test_key"] == "async_cm"
             await event.wait()
             cancel_called_not_cancel_called.append(scope.cancel_called)
 
@@ -154,12 +157,13 @@ async def test_cancellation_drain_mode(apgdriver: db.Driver) -> None:
     N = 10
     event = asyncio.Event()
     q = Queries(apgdriver)
-    qm = QueueManager(apgdriver)
+    qm = QueueManager(apgdriver, resources={"test_key": "drain"})
 
     @qm.entrypoint("to_be_canceled")
     async def to_be_canceled(job: Job) -> None:
         ctx = qm.get_context(job.id)
         with ctx.cancellation:
+            assert ctx.resources["test_key"] == "drain"
             await event.wait()
 
     jids = await q.enqueue(
