@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import sys
+from functools import partial
 from typing import Any, Callable
 from unittest.mock import Mock
 
@@ -117,6 +118,15 @@ def test_load_factory_sys_path_modified(monkeypatch: pytest.MonkeyPatch) -> None
         sys.path = original_sys_path
 
 
+def test_load_factory_with_callable() -> None:
+    def factory_function(arg: Any) -> Any:
+        return arg
+
+    factory_callable = partial(factory_function, arg=42)
+    factory_function_ = load_factory(factory_callable)
+    assert factory_function_() == 42
+
+
 async def test_run_factory_with_async_context_manager() -> None:
     """
     Test run_factory with an asynchronous context manager.
@@ -178,6 +188,11 @@ async def test_run_factory_with_invalid_input() -> None:
     """
     invalid_input: str = "not a valid input"
 
-    with pytest.raises(TypeError, match="object str can't be used in 'await' expression"):
+    with pytest.raises(TypeError) as exc_info:
         async with run_factory(invalid_input):  # type: ignore[arg-type]
             pass  # This line should not be reached
+
+    assert str(exc_info.value) in {
+        "object str can't be used in 'await' expression",
+        "'str' object can't be awaited",
+    }
